<tr>
  <td align="right" valign="top" width="30%"><b><font color="grey">{{ title }}</font></b></td>
  {% if value2 %}
    <td align="left" valign="top"><font>{{ value }}</font></td>
    <td align="left" valign="top"><font>{{ value2 }}</font></td>
  {% else %}
    <td align="left" valign="top" colspan="2"><font>{{ value }}</font></td>
  {% endif %}
</tr>
